@@ -1,3 +1,13 @@
+/*
+This file belong to
+minet: Mutual Information NETworks, <http://minet.meyerp.com>
+a package that implements various algorithms for inferring mutual information networks from data.
+
+Copyright (Creative Commons by-nc-sa) July 2010  Patrick Emmanuel Meyer <software@meyerp.com>
+<License full notice: at the root of the package 
+and at http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode> 
+*/
+
 #include "minet.h"
 SEXP clr( SEXP Rmim, SEXP Rsize )
 {
